@@ -136,7 +136,8 @@ class HandleScan:
             findings_list, input_core = runner_secret_scan(
                 dict_args,
                 config_tool["ENGINE_SECRET"]["TOOL"],
-                self.devops_platform_gateway
+                self.devops_platform_gateway,
+                secret_tool
             )
             if (
                 dict_args["use_vulnerability_management"] == "true"
